diff --git a/plugins-scripts/Makefile.am b/plugins-scripts/Makefile.am
index 01fca20..34f9921 100644
--- a/plugins-scripts/Makefile.am
+++ b/plugins-scripts/Makefile.am
@@ -20,11 +20,9 @@ TESTS = @SCRIPT_TEST@
 
 test:
 	perl -I $(top_builddir) -I $(top_srcdir) ../test.pl
-	perl -I $(top_builddir) -I $(top_srcdir) ../test.pl t/utils.t	# utils.t is excluded from above, so manually ask to test
 
 test-debug:
 	NPTEST_DEBUG=1 HARNESS_VERBOSE=1 perl -I $(top_builddir) -I $(top_srcdir) ../test.pl
-	NPTEST_DEBUG=1 HARNESS_VERBOSE=1 perl -I $(top_builddir) -I $(top_srcdir) ../test.pl t/utils.t	# utils.t is excluded from above, so manually ask to test
 
 CLEANFILES=$(libexec_SCRIPTS)
 
diff --git a/plugins-scripts/t/utils.pm.t b/plugins-scripts/t/utils.pm.t
new file mode 100644
index 0000000..f37f567
--- /dev/null
+++ b/plugins-scripts/t/utils.pm.t
@@ -0,0 +1,51 @@
+#!/usr/bin/perl -w -I ..
+#
+# utils.pm tests
+#
+# $Id$
+#
+# Run with perl t/utils.t
+
+use warnings;
+use strict;
+use Test::More;
+use NPTest;
+
+use lib "..";
+use utils;
+
+my $hostname_checks = {
+	"www.altinity.com" => 1,
+	"www.888.com" => 1,
+	"888.com" => 1,
+	"host-hyphened.com" => 1,
+	"rubbish" => 1,
+	"-start.com" => 0,
+	"nonfqdn-but-endsindot." => 1,
+	"fqdn.and.endsindot." => 1,
+	"lots.of.dots.dot.org" => 1,
+	"endingwithdoubledots.." => 0,
+	"toomany..dots" => 0,
+	".start.with.dot" => 0,
+	"10.20.30.40" => 1,
+	"10.20.30.40.50" => 0,
+	"10.20.30" => 0,
+	"10.20.30.40." => 1,	# This is considered a hostname because of trailing dot. It probably won't exist though...
+	"888." => 1,		# This is because it could be a domain
+	"host.888." => 1,
+	"where.did.that.!.come.from." => 0,
+	"no.underscores_.com" => 0,
+	"a.somecompany.com" => 1,
+	"host.a.com" => 1,
+	};
+
+plan tests => ((scalar keys %$hostname_checks) + 4);
+
+foreach my $h (sort keys %$hostname_checks) {
+	is (utils::is_hostname($h), $hostname_checks->{$h}, "$h should return ".$hostname_checks->{$h});
+}
+
+is(utils::is_hostname(), 0, "No parameter errors");
+is(utils::is_hostname(""), 0, "Empty string errors");
+is(utils::is_hostname(0), 0, "0 also errors");
+is(utils::is_hostname(1), 0, "1 also errors");
diff --git a/plugins-scripts/t/utils.t b/plugins-scripts/t/utils.t
deleted file mode 100644
index f37f567..0000000
--- a/plugins-scripts/t/utils.t
+++ /dev/null
@@ -1,51 +0,0 @@
-#!/usr/bin/perl -w -I ..
-#
-# utils.pm tests
-#
-# $Id$
-#
-# Run with perl t/utils.t
-
-use warnings;
-use strict;
-use Test::More;
-use NPTest;
-
-use lib "..";
-use utils;
-
-my $hostname_checks = {
-	"www.altinity.com" => 1,
-	"www.888.com" => 1,
-	"888.com" => 1,
-	"host-hyphened.com" => 1,
-	"rubbish" => 1,
-	"-start.com" => 0,
-	"nonfqdn-but-endsindot." => 1,
-	"fqdn.and.endsindot." => 1,
-	"lots.of.dots.dot.org" => 1,
-	"endingwithdoubledots.." => 0,
-	"toomany..dots" => 0,
-	".start.with.dot" => 0,
-	"10.20.30.40" => 1,
-	"10.20.30.40.50" => 0,
-	"10.20.30" => 0,
-	"10.20.30.40." => 1,	# This is considered a hostname because of trailing dot. It probably won't exist though...
-	"888." => 1,		# This is because it could be a domain
-	"host.888." => 1,
-	"where.did.that.!.come.from." => 0,
-	"no.underscores_.com" => 0,
-	"a.somecompany.com" => 1,
-	"host.a.com" => 1,
-	};
-
-plan tests => ((scalar keys %$hostname_checks) + 4);
-
-foreach my $h (sort keys %$hostname_checks) {
-	is (utils::is_hostname($h), $hostname_checks->{$h}, "$h should return ".$hostname_checks->{$h});
-}
-
-is(utils::is_hostname(), 0, "No parameter errors");
-is(utils::is_hostname(""), 0, "Empty string errors");
-is(utils::is_hostname(0), 0, "0 also errors");
-is(utils::is_hostname(1), 0, "1 also errors");
